/**
 * Module to extend collection functionalities.
 * @module CollectionExtend
 */
define([
  'underscore', 
  'backbone'
], function(
  _, 
  Backbone
) {

  return Backbone.Collection.extend({
    /**
     * Overriding collection fetch during to ensure persisted 
     * attribute to prevent for id mutation.
     * @access public
     * @param object options
     */ 
    fetch: function(options) {
      options = options ? _.clone(options) : {};
      if (options.parse === void 0) options.parse = true;
      var success = options.success;
      var collection = this;

      // Wrap an optional error callback with a fallback error event.
      var wrapError = function(model, options) {
        var error = options.error;
        options.error = function(resp) {
          if (error) error(model, resp, options);
          model.trigger('error', model, resp, options);
        };
      };

      options.success = function(resp) {
        var method = options.reset ? 'reset' : 'set';
        collection[method](resp, options);

        /* Set model.persisted params to true. */
        collection.forEach(function(model) {
          model.persisted = true;
        });

        if (success) success(collection, resp, options);
        collection.trigger('sync', collection, resp, options);
      };
      wrapError(this, options);
      return this.sync('read', this, options);
    }
  });
});
