define([
    'underscore', 
    'backbone'
  ], function(
    _, 
    Backbone
  ) {
  'use strict';

  return Backbone.Model.extend({
    /* Variables */
    name: 'Access',
    token: null,
    active: false,
    defaults: {
      name : null,
      type : null
    },
    /* Methods */
    initialize: function(options){
      this.baseApiUrl = options.baseApiUrl;
      this.token = options.token;
    },
    baseApiUrl: function(username){
      return 'https://'+username+'.rec.la';
    },
    getInfoUrl: function(){
      return this.baseApiUrl + '/access-info?auth='+encodeURIComponent(this.token)
    },
    parse: function(resp, options){
      var parsedResponse = {};
      _.extend(parsedResponse, resp);

      if (resp.permissions && resp.permissions.length){
        parsedResponse.permissions = {};
        resp.permissions.forEach(function(perm){
          var channelData = {
            level:perm.level
          };
          if (perm.folderPermissions && perm.folderPermissions.length){
            channelData.folders = {};
            perm.folderPermissions.forEach(function(folderPerm){
              if(folderPerm.folderId === null){
                folderPerm.folderId = 'null';
              }
              channelData.folders[folderPerm.folderId] = folderPerm.level;
            });
          }
          parsedResponse.permissions[perm.channelId] = channelData;
        }, this);
      }
      return parsedResponse;
    }
  });

});
